==> cloudsnorkel.cdk_github_runners-0.10.3-py3-none-any.whl: package/assets/providers/update-lambda.lambda/index.js <==
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/providers/update-lambda.lambda.ts
var update_lambda_lambda_exports = {};
__export(update_lambda_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(update_lambda_lambda_exports);
var AWS = __toESM(require("aws-sdk"));
var lambda = new AWS.Lambda();
function sleep(ms) {
  return new Promise((resolve) => setTimeout(resolve, ms));
}
async function handler(event) {
  console.log(JSON.stringify(event));
  while (true) {
    try {
      await lambda.updateFunctionCode({
        FunctionName: event.lambdaName,
        ImageUri: `${event.repositoryUri}:${event.repositoryTag}`,
        Publish: true
      }).promise();
      break;
    } catch (e) {
      if (e.code == "ResourceConflictException") {
        await sleep(1e4);
      } else {
        throw e;
      }
    }
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});

==> cloudsnorkel.cdk_github_runners-0.13.2-py3-none-any.whl: package/assets/providers/update-lambda.lambda/index.js <==
"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/providers/update-lambda.lambda.ts
var update_lambda_lambda_exports = {};
__export(update_lambda_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(update_lambda_lambda_exports);
var import_client_lambda = require("@aws-sdk/client-lambda");
var lambda = new import_client_lambda.LambdaClient();
function sleep(ms) {
  return new Promise((resolve) => setTimeout(resolve, ms));
}
async function handler(event) {
  console.log(event);
  while (true) {
    try {
      await lambda.send(new import_client_lambda.UpdateFunctionCodeCommand({
        FunctionName: event.lambdaName,
        ImageUri: `${event.repositoryUri}:${event.repositoryTag}`,
        Publish: true
      }));
      break;
    } catch (e) {
      if (e instanceof import_client_lambda.ResourceConflictException) {
        await sleep(1e4);
      } else {
        throw e;
      }
    }
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
